@@ -1,7 +1,7 @@
 package Module::Path::More;
 
-our $DATE = '2016-08-03'; # DATE
-our $VERSION = '0.31'; # VERSION
+our $DATE = '2017-02-01'; # DATE
+our $VERSION = '0.32'; # VERSION
 
 use 5.010001;
 use strict;
@@ -38,7 +38,7 @@ $SPEC{module_path} = {
 Search `@INC` (reference entries are skipped) and return path(s) to Perl module
 files with the requested name.
 
-This function is like the one from `Module::Path`, except with a different
+This function is like the one from <pm:Module::Path>, except with a different
 interface and more options (finding all matches instead of the first, the option
 of not absolutizing paths, finding `.pmc` & `.pod` files, finding module
 prefixes).
@@ -53,23 +53,58 @@ _
         },
         find_pm => {
             summary => 'Whether to find .pm files',
-            schema  => 'bool',
+            schema  => ['int*', min=>0],
             default => 1,
+            description => <<'_',
+
+The value of this option is an integer number from 0. 0 means to not search for
+.pm files, while number larger than 0 means to search for .pm files. The larger
+the number, the lower the priority. If more than one type is found (prefix, .pm,
+.pmc, .pod) then the type with the lowest number is returned first.
+
+_
         },
         find_pmc => {
             summary => 'Whether to find .pmc files',
-            schema  => 'bool',
-            default => 1,
+            schema  => ['int*', min=>0],
+            default => 2,
+            description => <<'_',
+
+The value of this option is an integer number from 0. 0 means to not search for
+.pmc files, while number larger than 0 means to search for .pmc files. The
+larger the number, the lower the priority. If more than one type is found
+(prefix, .pm, .pmc, .pod) then the type with the lowest number is returned
+first.
+
+_
         },
         find_pod => {
             summary => 'Whether to find .pod files',
-            schema  => 'bool',
+            schema  => ['int*', min=>0],
             default => 0,
+            description => <<'_',
+
+The value of this option is an integer number from 0. 0 means to not search for
+.pod files, while number larger than 0 means to search for .pod files. The
+larger the number, the lower the priority. If more than one type is found
+(prefix, .pm, .pmc, .pod) then the type with the lowest number is returned
+first.
+
+_
         },
         find_prefix => {
             summary => 'Whether to find module prefixes',
-            schema  => 'bool',
+            schema  => ['int*', min=>0],
             default => 0,
+            description => <<'_',
+
+The value of this option is an integer number from 0. 0 means to not search for
+module prefix, while number larger than 0 means to search for module prefix. The
+larger the number, the lower the priority. If more than one type is found
+(prefix, .pm, .pmc, .pod) then the type with the lowest number is returned
+first.
+
+_
         },
         all => {
             summary => 'Return all results instead of just the first',
@@ -86,6 +121,20 @@ _
         schema => ['any' => of => ['str*', ['array*' => of => 'str*']]],
     },
     result_naked => 1,
+    examples => [
+        {
+            summary => 'Find the first Foo::Bar (.pm or .pmc) in @INC',
+            args => {module => 'Foo::Bar'},
+        },
+        {
+            summary => 'Find all Foo::Bar (.pm or .pmc) in @INC, return absolute paths',
+            args => {module => 'Foo::Bar', all => 1, abs => 1},
+        },
+        {
+            summary => 'Find the Rinci (.pod first, then .pm) in @INC',
+            args => {module => 'Rinci', find_pod => 1, find_pm => 2, find_pmc => 0},
+        },
+    ],
 };
 sub module_path {
     my %args = @_;
@@ -95,14 +144,23 @@ sub module_path {
     $args{abs}         //= 0;
     $args{all}         //= 0;
     $args{find_pm}     //= 1;
-    $args{find_pmc}    //= 1;
+    $args{find_pmc}    //= 2;
     $args{find_pod}    //= 0;
     $args{find_prefix} //= 0;
 
     require Cwd if $args{abs};
 
     my @res;
-    my $add = sub { push @res, $args{abs} ? Cwd::abs_path($_[0]) : $_[0] };
+    my %unfound = (
+        ("pm" => 1)     x !!$args{find_pm},
+        ("pmc" => 1)    x !!$args{find_pmc},
+        ("pod" => 1)    x !!$args{find_pod},
+        ("prefix" => 1) x !!$args{find_prefix},
+    );
+    my $add = sub {
+        my ($path, $prio) = @_;
+        push @res, [$args{abs} ? Cwd::abs_path($path) : $path, $prio];
+    };
 
     my $relpath;
 
@@ -114,35 +172,41 @@ sub module_path {
         next if ref($dir);
 
         my $prefix = $dir . $SEPARATOR . $relpath;
-        if ($args{find_pmc}) {
-            my $file = $prefix . ".pmc";
-            if (-f $file) {
-                $add->($file);
-                last unless $args{all};
-            }
-        }
         if ($args{find_pm}) {
             my $file = $prefix . ".pm";
             if (-f $file) {
-                $add->($file);
-                last unless $args{all};
+                $add->($file, $args{find_pm});
+                delete $unfound{pm};
+                last if !keys(%unfound) && !$args{all};
+            }
+        }
+        if ($args{find_pmc}) {
+            my $file = $prefix . ".pmc";
+            if (-f $file) {
+                $add->($file, $args{find_pmc});
+                delete $unfound{pmc};
+                last if !keys(%unfound) && !$args{all};
             }
         }
         if ($args{find_pod}) {
             my $file = $prefix . ".pod";
             if (-f $file) {
-                $add->($file);
-                last unless $args{all};
+                $add->($file, $args{find_pod});
+                delete $unfound{pod};
+                last if !keys(%unfound) && !$args{all};
             }
         }
         if ($args{find_prefix}) {
             if (-d $prefix) {
-                $add->($prefix);
-                last unless $args{all};
+                $add->($prefix, $args{find_prefix});
+                delete $unfound{prefix};
+                last if !keys(%unfound) && !$args{all};
             }
         }
     }
 
+    @res = map { $_->[0] } sort { $a->[1] <=> $b->[1] } @res;
+
     if ($args{all}) {
         return \@res;
     } else {
@@ -202,7 +266,7 @@ Module::Path::More - Get path to locally installed Perl module
 
 =head1 VERSION
 
-This document describes version 0.31 of Module::Path::More (from Perl distribution Module-Path-More), released on 2016-08-03.
+This document describes version 0.32 of Module::Path::More (from Perl distribution Module-Path-More), released on 2017-02-01.
 
 =head1 SYNOPSIS
 
@@ -262,10 +326,32 @@ other hand this method can avoid actual loading of the module.
 
 Get path to locally installed Perl module.
 
+Examples:
+
+=over
+
+=item * Find the first Foo::Bar (.pm or .pmc) in @INC:
+
+ module_path(module => "Foo::Bar"); # -> undef
+
+=item * Find all Foo::Bar (.pm or .pmc) in @INC, return absolute paths:
+
+ module_path(module => "Foo::Bar", abs => 1, all => 1); # -> []
+
+=item * Find the Rinci (.pod first, then .pm) in @INC:
+
+ module_path(module => "Rinci", find_pm => 2, find_pmc => 0, find_pod => 1);
+
+Result:
+
+ "/home/u1/perl5/perlbrew/perls/perl-5.24.0/lib/site_perl/5.24.0/Rinci.pod"
+
+=back
+
 Search C<@INC> (reference entries are skipped) and return path(s) to Perl module
 files with the requested name.
 
-This function is like the one from C<Module::Path>, except with a different
+This function is like the one from L<Module::Path>, except with a different
 interface and more options (finding all matches instead of the first, the option
 of not absolutizing paths, finding C<.pmc> & C<.pod> files, finding module
 prefixes).
@@ -284,22 +370,45 @@ Whether to return absolute paths.
 
 Return all results instead of just the first.
 
-=item * B<find_pm> => I<bool> (default: 1)
+=item * B<find_pm> => I<int> (default: 1)
 
 Whether to find .pm files.
 
-=item * B<find_pmc> => I<bool> (default: 1)
+The value of this option is an integer number from 0. 0 means to not search for
+.pm files, while number larger than 0 means to search for .pm files. The larger
+the number, the lower the priority. If more than one type is found (prefix, .pm,
+.pmc, .pod) then the type with the lowest number is returned first.
+
+=item * B<find_pmc> => I<int> (default: 2)
 
 Whether to find .pmc files.
 
-=item * B<find_pod> => I<bool> (default: 0)
+The value of this option is an integer number from 0. 0 means to not search for
+.pmc files, while number larger than 0 means to search for .pmc files. The
+larger the number, the lower the priority. If more than one type is found
+(prefix, .pm, .pmc, .pod) then the type with the lowest number is returned
+first.
+
+=item * B<find_pod> => I<int> (default: 0)
 
 Whether to find .pod files.
 
-=item * B<find_prefix> => I<bool> (default: 0)
+The value of this option is an integer number from 0. 0 means to not search for
+.pod files, while number larger than 0 means to search for .pod files. The
+larger the number, the lower the priority. If more than one type is found
+(prefix, .pm, .pmc, .pod) then the type with the lowest number is returned
+first.
+
+=item * B<find_prefix> => I<int> (default: 0)
 
 Whether to find module prefixes.
 
+The value of this option is an integer number from 0. 0 means to not search for
+module prefix, while number larger than 0 means to search for module prefix. The
+larger the number, the lower the priority. If more than one type is found
+(prefix, .pm, .pmc, .pod) then the type with the lowest number is returned
+first.
+
 =item * B<module>* => I<str>
 
 Module name to search.
@@ -345,7 +454,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Module-Pat
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Module-Path-More>.
+Source repository is at L<https://github.com/perlancar/perl-Alt-Module-Path-SHARYANTO>.
 
 =head1 BUGS
 
@@ -394,7 +503,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
